/****************************************************************************
** Meta object code from reading C++ file 'window.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../layer-shell-qt-5.27.12/src/interfaces/window.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'window.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_LayerShellQt__Window_t {
    QByteArrayData data[21];
    char stringdata0[333];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_LayerShellQt__Window_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_LayerShellQt__Window_t qt_meta_stringdata_LayerShellQt__Window = {
    {
QT_MOC_LITERAL(0, 0, 20), // "LayerShellQt::Window"
QT_MOC_LITERAL(1, 21, 14), // "anchorsChanged"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 20), // "exclusionZoneChanged"
QT_MOC_LITERAL(4, 58, 14), // "marginsChanged"
QT_MOC_LITERAL(5, 73, 28), // "keyboardInteractivityChanged"
QT_MOC_LITERAL(6, 102, 12), // "layerChanged"
QT_MOC_LITERAL(7, 115, 6), // "Anchor"
QT_MOC_LITERAL(8, 122, 9), // "AnchorTop"
QT_MOC_LITERAL(9, 132, 12), // "AnchorBottom"
QT_MOC_LITERAL(10, 145, 10), // "AnchorLeft"
QT_MOC_LITERAL(11, 156, 11), // "AnchorRight"
QT_MOC_LITERAL(12, 168, 5), // "Layer"
QT_MOC_LITERAL(13, 174, 15), // "LayerBackground"
QT_MOC_LITERAL(14, 190, 11), // "LayerBottom"
QT_MOC_LITERAL(15, 202, 8), // "LayerTop"
QT_MOC_LITERAL(16, 211, 12), // "LayerOverlay"
QT_MOC_LITERAL(17, 224, 21), // "KeyboardInteractivity"
QT_MOC_LITERAL(18, 246, 25), // "KeyboardInteractivityNone"
QT_MOC_LITERAL(19, 272, 30), // "KeyboardInteractivityExclusive"
QT_MOC_LITERAL(20, 303, 29) // "KeyboardInteractivityOnDemand"

    },
    "LayerShellQt::Window\0anchorsChanged\0"
    "\0exclusionZoneChanged\0marginsChanged\0"
    "keyboardInteractivityChanged\0layerChanged\0"
    "Anchor\0AnchorTop\0AnchorBottom\0AnchorLeft\0"
    "AnchorRight\0Layer\0LayerBackground\0"
    "LayerBottom\0LayerTop\0LayerOverlay\0"
    "KeyboardInteractivity\0KeyboardInteractivityNone\0"
    "KeyboardInteractivityExclusive\0"
    "KeyboardInteractivityOnDemand"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_LayerShellQt__Window[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       3,   44, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   39,    2, 0x06 /* Public */,
       3,    0,   40,    2, 0x06 /* Public */,
       4,    0,   41,    2, 0x06 /* Public */,
       5,    0,   42,    2, 0x06 /* Public */,
       6,    0,   43,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // enums: name, alias, flags, count, data
       7,    7, 0x0,    4,   59,
      12,   12, 0x0,    4,   67,
      17,   17, 0x0,    3,   75,

 // enum data: key, value
       8, uint(LayerShellQt::Window::AnchorTop),
       9, uint(LayerShellQt::Window::AnchorBottom),
      10, uint(LayerShellQt::Window::AnchorLeft),
      11, uint(LayerShellQt::Window::AnchorRight),
      13, uint(LayerShellQt::Window::LayerBackground),
      14, uint(LayerShellQt::Window::LayerBottom),
      15, uint(LayerShellQt::Window::LayerTop),
      16, uint(LayerShellQt::Window::LayerOverlay),
      18, uint(LayerShellQt::Window::KeyboardInteractivityNone),
      19, uint(LayerShellQt::Window::KeyboardInteractivityExclusive),
      20, uint(LayerShellQt::Window::KeyboardInteractivityOnDemand),

       0        // eod
};

void LayerShellQt::Window::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Window *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->anchorsChanged(); break;
        case 1: _t->exclusionZoneChanged(); break;
        case 2: _t->marginsChanged(); break;
        case 3: _t->keyboardInteractivityChanged(); break;
        case 4: _t->layerChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (Window::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Window::anchorsChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (Window::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Window::exclusionZoneChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (Window::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Window::marginsChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (Window::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Window::keyboardInteractivityChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (Window::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Window::layerChanged)) {
                *result = 4;
                return;
            }
        }
    }
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject LayerShellQt::Window::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_LayerShellQt__Window.data,
    qt_meta_data_LayerShellQt__Window,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *LayerShellQt::Window::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LayerShellQt::Window::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_LayerShellQt__Window.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int LayerShellQt::Window::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void LayerShellQt::Window::anchorsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void LayerShellQt::Window::exclusionZoneChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void LayerShellQt::Window::marginsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void LayerShellQt::Window::keyboardInteractivityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void LayerShellQt::Window::layerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
